@@ -87,9 +87,9 @@ setMethod(
   "igirf",
   signature=signature(data="spatPomp"),
   definition=function (data,Ngirf,Np,rw.sd,cooling.type,cooling.fraction.50,
-                        Ninter,lookahead=1,Nguide,kind=c('bootstrap', 'moment'),
-                        tol = 1e-300,
-                        ..., verbose = getOption("verbose", FALSE)) {
+    Ninter,lookahead=1,Nguide,kind=c('bootstrap', 'moment'),
+    tol = 1e-300,
+    ..., verbose = getOption("verbose", FALSE)) {
     if(missing(Ninter)) Ninter <- length(unit_names(data))
     kind = match.arg(kind)
     tryCatch(
@@ -109,8 +109,8 @@ setMethod(
   "igirf",
   signature=signature(data="igirfd_spatPomp"),
   function (data,Ngirf,Np,rw.sd,cooling.type, cooling.fraction.50, Ninter,
-            lookahead,Nguide,kind=c('bootstrap','moment'),tol, ...,
-            verbose = getOption("verbose", FALSE)) {
+    lookahead,Nguide,kind=c('bootstrap','moment'),tol, ...,
+    verbose = getOption("verbose", FALSE)) {
     if (missing(Ngirf)) Ngirf <- data@Ngirf
     if (missing(rw.sd)) rw.sd <- data@rw.sd
     if (missing(cooling.type)) cooling.type <- data@cooling.type
@@ -122,30 +122,30 @@ setMethod(
     if (missing(lookahead)) lookahead <- data@lookahead
 
     igirf(as(data,"spatPomp"), Ngirf=Ngirf, Np=Np,rw.sd = rw.sd, cooling.type = cooling.type,
-         cooling.fraction.50 = cooling.fraction.50, tol=tol, Ninter=Ninter, Nguide=Nguide,
-         kind=kind, lookahead=lookahead, ..., verbose=verbose)
+      cooling.fraction.50 = cooling.fraction.50, tol=tol, Ninter=Ninter, Nguide=Nguide,
+      kind=kind, lookahead=lookahead, ..., verbose=verbose)
   }
 )
 
 igirf.internal <- function (object,Ngirf,Np,rw.sd,cooling.type,cooling.fraction.50,
-                            Ninter,lookahead,Nguide,kind,
-                            tol, ...,
-                            .ndone = 0L, .indices = integer(0),.paramMatrix = NULL,.gnsi = TRUE, verbose = FALSE) {
+  Ninter,lookahead,Nguide,kind,
+  tol, ...,
+  .ndone = 0L, .indices = integer(0),.paramMatrix = NULL,.gnsi = TRUE, verbose = FALSE) {
 
   verbose <- as.logical(verbose)
   p_object <- pomp(object,...,verbose=verbose)
   object <- new("spatPomp",p_object,
-                     unit_covarnames = object@unit_covarnames,
-                     shared_covarnames = object@shared_covarnames,
-                     runit_measure = object@runit_measure,
-                     dunit_measure = object@dunit_measure,
-                     eunit_measure = object@eunit_measure,
-                     munit_measure = object@munit_measure,
-                     vunit_measure = object@vunit_measure,
-                     unit_names=object@unit_names,
-                     unitname=object@unitname,
-                     unit_statenames=object@unit_statenames,
-                     unit_obsnames = object@unit_obsnames)
+    unit_covarnames = object@unit_covarnames,
+    shared_covarnames = object@shared_covarnames,
+    runit_measure = object@runit_measure,
+    dunit_measure = object@dunit_measure,
+    eunit_measure = object@eunit_measure,
+    munit_measure = object@munit_measure,
+    vunit_measure = object@vunit_measure,
+    unit_names=object@unit_names,
+    unitname=object@unitname,
+    unit_statenames=object@unit_statenames,
+    unit_obsnames = object@unit_obsnames)
   if (undefined(object@rprocess) || undefined(object@dmeasure))
     stop(paste(sQuote(c("rprocess","dmeasure")),collapse=", ")," are needed basic components.")
 
@@ -170,12 +170,12 @@ igirf.internal <- function (object,Ngirf,Np,rw.sd,cooling.type,cooling.fraction.
       vapply(seq_len(ntimes),Np,numeric(1)),
       error = function (e) {
         stop("if ",sQuote("Np"),
-               " is a function, it must return a single positive integer.")
+          " is a function, it must return a single positive integer.")
       }
     )
   } else if (!is.numeric(Np)) {
     stop(sQuote("Np"),
-           " must be a number, a vector of numbers, or a function.")
+      " must be a number, a vector of numbers, or a function.")
   }
 
   if (length(Np) == 1) {
@@ -187,7 +187,7 @@ igirf.internal <- function (object,Ngirf,Np,rw.sd,cooling.type,cooling.fraction.
     Np <- head(Np,ntimes)
   } else if (length(Np) < ntimes) {
     stop(sQuote("Np")," must have length 1 or ",
-           sQuote("length(time(object))"),".")
+      sQuote("length(time(object))"),".")
   }
 
   if (!all(is.finite(Np)) || any(Np <= 0))
@@ -198,15 +198,15 @@ igirf.internal <- function (object,Ngirf,Np,rw.sd,cooling.type,cooling.fraction.
 
   if (missing(rw.sd))
     stop(sQuote("rw.sd")," must be specified!")
-  #rw.sd <- perturbn.kernel.sd(rw.sd,time=time(object),paramnames=names(start))
+  ##rw.sd <- perturbn.kernel.sd(rw.sd,time=time(object),paramnames=names(start))
   rw.sd <- perturbn.kernel.sd(rw.sd,
-                                     time=igirf_rw_sd_times(times=time(object),Ninter=Ninter),
-                                     paramnames=names(start))
+    time=igirf_rw_sd_times(times=time(object),Ninter=Ninter),
+    paramnames=names(start))
   if (missing(cooling.fraction.50))
     stop(sQuote("cooling.fraction.50")," is a required argument.")
   if (length(cooling.fraction.50) != 1 || !is.numeric(cooling.fraction.50) ||
-      !is.finite(cooling.fraction.50) || cooling.fraction.50 <= 0 ||
-      cooling.fraction.50 > 1)
+        !is.finite(cooling.fraction.50) || cooling.fraction.50 <= 0 ||
+          cooling.fraction.50 > 1)
     stop(sQuote("cooling.fraction.50")," must be in (0,1].")
   cooling.fraction.50 <- as.numeric(cooling.fraction.50)
 
@@ -218,36 +218,37 @@ igirf.internal <- function (object,Ngirf,Np,rw.sd,cooling.type,cooling.fraction.
 
   if (is.null(.paramMatrix)) {
     paramMatrix <- array(data=start,dim=c(length(start),Np[1L]),
-                         dimnames=list(variable=names(start),rep=NULL))
+      dimnames=list(variable=names(start),rep=NULL))
   } else {
     paramMatrix <- .paramMatrix
   }
 
   traces <- array(dim=c(Ngirf+1,length(start)+1),
-                  dimnames=list(iteration=seq.int(.ndone,.ndone+Ngirf),
-                                variable=c('loglik',names(start))))
+    dimnames=list(iteration=seq.int(.ndone,.ndone+Ngirf),
+      variable=c('loglik',names(start))))
   traces[1L,] <- c(NA,start)
 
   pompLoad(object,verbose=verbose)
   on.exit(pompUnload(object,verbose=verbose))
 
   paramMatrix <- partrans(object,paramMatrix,dir="toEst",
-                          .gnsi=gnsi)
+    .gnsi=gnsi)
 
   ## iterate the filtering
   for (n in seq_len(Ngirf)) {
     if(kind == 'moment'){
       g <- igirf.momgirf(object=object,Ninter=Ninter,Nguide=Nguide,lookahead=lookahead,
-                      params=paramMatrix,
-                      Np=Np,girfiter=.ndone+n,cooling.fn=cooling.fn,rw.sd=rw.sd,tol=tol,
-                      verbose=verbose,.indices=.indices, .gnsi=gnsi)
+        params=paramMatrix,
+        Np=Np,girfiter=.ndone+n,cooling.fn=cooling.fn,rw.sd=rw.sd,tol=tol,
+        verbose=verbose,.indices=.indices, .gnsi=gnsi)
     }
     if(kind == 'bootstrap'){
-      g <- igirf.bootgirf(object=object,Ninter=Ninter,Nguide=Nguide,lookahead=lookahead,
-                      params=paramMatrix,
-                      Np=Np,girfiter=.ndone+n,cooling.fn=cooling.fn,rw.sd=rw.sd,tol=tol,
-                      verbose=verbose,.indices=.indices, .gnsi=gnsi)
-
+      g <- igirf.bootgirf(
+        object=object,Ninter=Ninter,Nguide=Nguide,lookahead=lookahead,
+        params=paramMatrix,
+        Np=Np,girfiter=.ndone+n,cooling.fn=cooling.fn,rw.sd=rw.sd,tol=tol,
+        verbose=verbose,.indices=.indices, .gnsi=gnsi
+      )
     }
     gnsi <- FALSE
 
@@ -263,7 +264,7 @@ igirf.internal <- function (object,Ngirf,Np,rw.sd,cooling.type,cooling.fraction.
   }
 
   g@paramMatrix <- partrans(object,paramMatrix,dir="fromEst",
-                              .gnsi=gnsi)
+    .gnsi=gnsi)
 
   new(
     "igirfd_spatPomp",
@@ -277,8 +278,8 @@ igirf.internal <- function (object,Ngirf,Np,rw.sd,cooling.type,cooling.fraction.
 }
 
 igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
-                        Np, girfiter, rw.sd, cooling.fn, tol,
-                        ..., verbose, .indices = integer(0), .gnsi = TRUE) {
+  Np, girfiter, rw.sd, cooling.fn, tol,
+  ..., verbose, .indices = integer(0), .gnsi = TRUE) {
 
   tol <- as.numeric(tol)
   gnsi <- as.logical(.gnsi)
@@ -298,42 +299,47 @@ igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
   ntimes <- length(times)-1
   nunits <- length(unit_names(object))
 
-  loglik <- rep(NA,ntimes)
   cond.loglik <- array(0, dim = c(ntimes, Ninter))
 
   znames <- object@accumvars
 
-  # Initialize filter guide function
+                                        # Initialize filter guide function
   log_filter_guide_fun <- array(0, dim = Np[1])
   for (nt in 0:(ntimes-1)) {
     pmag <- cooling.fn(nt,girfiter)$alpha*rw.sd[,nt]
-    params <- .Call("randwalk_perturbation_spatPomp",params,pmag,PACKAGE="spatPomp")
+    params <- .Call(randwalk_perturbation_spatPomp,params,pmag)
     tparams <- partrans(object,params,dir="fromEst",.gnsi=gnsi)
     if (nt == 0) {
       x <- rinit(object,params=tparams)
       statenames <- rownames(x)
-      paramnames <- rownames(tparams)
-      nvars <- nrow(x)
     }
-    # Intermediate times. using seq to get S+1 points between t_n and t_{n+1} inclusive
+    ## Intermediate times. using seq to get S+1 points between t_n and t_{n+1} inclusive
     tt <- seq(from=times[nt+1],to=times[nt+2],length.out=Ninter+1)
-    lookahead_steps = min(lookahead, ntimes-nt)
-    # Four-dimensional array: nvars by nguide by ntimes by nreps
-    Xg = array(0, dim=c(length(statenames), Nguide, lookahead_steps, Np[1]), dimnames = list(nvars = statenames, ng = NULL, lookahead = 1:lookahead_steps, nreps = NULL))
-    # For each particle get K guide particles, and fill in sample variance over K for each (lookahead value - unit - particle) combination
+    lookahead_steps <- min(lookahead, ntimes-nt)
+    ## Four-dimensional array: nvars by nguide by ntimes by nreps
+    Xg <- array(0,
+      dim=c(length(statenames), Nguide, lookahead_steps, Np[1]),
+      dimnames = list(
+        nvars = statenames,
+        ng = NULL,
+        lookahead = seq_len(lookahead_steps),
+        nreps = NULL
+      )
+    )
+                                        # For each particle get K guide particles, and fill in sample variance over K for each (lookahead value - unit - particle) combination
     fcst_samp_var <- array(0, dim = c(length(unit_names(object)), lookahead_steps, Np[1]))
     x_with_guides <- x[,rep(1:Np[1], rep(Nguide, Np[1]))]
     tp_with_guides <- tparams[,rep(1:Np[1], rep(Nguide, Np[1]))]
     Xg <- rprocess(object, x0=x_with_guides, t0=times[nt+1], times=times[(nt+2):(nt+1+lookahead_steps)],
-                   params=tp_with_guides,.gnsi=gnsi)
+      params=tp_with_guides,.gnsi=gnsi)
     xx <- tryCatch(
-      .Call('do_fcst_samp_var',
-            object=object,
-            X=Xg,
-            Np = as.integer(Np[1]),
-            times=times[(nt+2):(nt+1+lookahead_steps)],
-            params=tp_with_guides,
-            gnsi=TRUE),
+      .Call(do_fcst_samp_var,
+        object=object,
+        X=Xg,
+        Np = as.integer(Np[1]),
+        times=times[(nt+2):(nt+1+lookahead_steps)],
+        params=tp_with_guides,
+        gnsi=TRUE),
       error = function (e) {
         stop(ep,conditionMessage(e),call.=FALSE) # nocov
       }
@@ -343,9 +349,9 @@ igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
 
     for (s in 1:Ninter){
       tparams <- partrans(object,params,dir="fromEst",.gnsi=gnsi)
-      # Get prediction simulations: nvars by nreps by 1 array
+                                        # Get prediction simulations: nvars by nreps by 1 array
       X <- rprocess(object,x0=x, t0 = tt[s], times= tt[s+1],
-                    params=tparams,.gnsi=gnsi)
+        params=tparams,.gnsi=gnsi)
       if(s>1 && length(znames)>0){
         x.znames <- x[znames,]; dim(x.znames) <- c(dim(x.znames),1)
         X[znames,,] <- X[znames,,,drop=FALSE] + x.znames
@@ -353,11 +359,11 @@ igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
       X.start <- X[,,1]
       if(tt[s+1] < times[nt + 1 + lookahead_steps]){
         skel <- pomp::flow(object,
-                       x0=X.start,
-                       t0=tt[s+1],
-                       params=tparams,
-                       times = times[(nt + 1 + 1):(nt + 1 + lookahead_steps)],
-                       method = 'adams')
+          x0=X.start,
+          t0=tt[s+1],
+          params=tparams,
+          times = times[(nt + 1 + 1):(nt + 1 + lookahead_steps)],
+          method = 'adams')
         skel.start <- skel[,,1]
         X.start.znames <- X.start[znames,]
         skel.start.znames <- skel.start[znames,]
@@ -367,13 +373,13 @@ igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
         skel <- X
       }
       meas_var_skel <- tryCatch(
-        .Call('do_theta_to_v',
-              object=object,
-              X=skel,
-              Np = as.integer(Np[1]),
-              times=times[(nt+2):(nt+1+lookahead_steps)],
-              params=tparams,
-              gnsi=TRUE),
+        .Call(do_theta_to_v,
+          object=object,
+          X=skel,
+          Np = as.integer(Np[1]),
+          times=times[(nt+2):(nt+1+lookahead_steps)],
+          params=tparams,
+          gnsi=TRUE),
         error = function (e) {
           stop(ep,conditionMessage(e),call.=FALSE) # nocov
         }
@@ -385,14 +391,14 @@ igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
       array.tparams <- array(NA, dim = c(dim(tparams)[1], length(unit_names(object)), Np[1], lookahead_steps), dimnames = list(tparams = rownames(tparams)))
       for(i in 1:length(unit_names(object))) array.tparams[,i,,1:lookahead_steps] <- tparams
       mmp <- tryCatch(
-        .Call('do_v_to_theta',
-              object=object,
-              X=skel,
-              vc=inflated_var,
-              Np = as.integer(Np[1]),
-              times=times[(nt+2):(nt+1+lookahead_steps)],
-              params=array.tparams,
-              gnsi=TRUE),
+        .Call(do_v_to_theta,
+          object=object,
+          X=skel,
+          vc=inflated_var,
+          Np = as.integer(Np[1]),
+          times=times[(nt+2):(nt+1+lookahead_steps)],
+          params=array.tparams,
+          gnsi=TRUE),
         error = function (e) {
           stop(ep,conditionMessage(e),call.=FALSE) # nocov
         }
@@ -400,29 +406,29 @@ igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
       mom_match_param <- mmp
       dim(mom_match_param) <- c(dim(tparams)[1], length(unit_names(object)), lookahead_steps, Np[1])
       dimnames(mom_match_param) <- list(tparam = rownames(tparams))
-      log_guide_fun = vector(mode = "numeric", length = Np[1]) + 1
+      log_guide_fun <- vector(mode = "numeric", length = Np[1]) + 1
 
       for(l in 1:lookahead_steps){
-        if(nt+1+l-lookahead <= 0) discount_denom_init = object@t0
-        else discount_denom_init = times[nt+1+l - lookahead]
-        discount_factor = 1 - (times[nt+1+l] - tt[s+1])/(times[nt+1+l] - discount_denom_init)/ifelse(lookahead==1,2,1) ## to ensure that the discount factor does not become too small for L=1 and small s (which can lead to very uninformative guide function), increase the discount factor to at least 1/2 when L=1.
+        if(nt+1+l-lookahead <= 0) discount_denom_init <- object@t0
+        else discount_denom_init <- times[nt+1+l - lookahead]
+        discount_factor <- 1 - (times[nt+1+l] - tt[s+1])/(times[nt+1+l] - discount_denom_init)/ifelse(lookahead==1,2,1) ## to ensure that the discount factor does not become too small for L=1 and small s (which can lead to very uninformative guide function), increase the discount factor to at least 1/2 when L=1.
         log_dmeas_weights <- tryCatch(
-          (vec_dmeasure(
-            object,
-            y=object@data[,nt+l,drop=FALSE],
-            x=skel[,,l,drop = FALSE],
-            times=times[nt+1+l],
-            params=mom_match_param[,,l,],
-            log=TRUE,
-            .gnsi=gnsi
-          )),
-          error = function (e) {
-            stop(ep,"error in calculation of log_dmeas_weights: ",
-                 conditionMessage(e),call.=FALSE)
-          }
+        (vec_dmeasure(
+          object,
+          y=object@data[,nt+l,drop=FALSE],
+          x=skel[,,l,drop = FALSE],
+          times=times[nt+1+l],
+          params=mom_match_param[,,l,],
+          log=TRUE,
+          .gnsi=gnsi
+        )),
+        error = function (e) {
+          stop(ep,"error in calculation of log_dmeas_weights: ",
+            conditionMessage(e),call.=FALSE)
+        }
         )
         if(any(is.na(log_dmeas_weights))){
-          # find particle with the NA
+                                        # find particle with the NA
           na_ix <- which(is.na(log_dmeas_weights[,,1]))[1]
           na_ix_col <- (na_ix %/% nunits) + (na_ix %% nunits > 0)
           illegal_dunit_measure_error(
@@ -434,7 +440,7 @@ igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
           )
         }
         log_resamp_weights <- apply(log_dmeas_weights[,,1,drop=FALSE], 2, function(x) sum(x))*discount_factor
-        log_guide_fun = log_guide_fun + log_resamp_weights
+        log_guide_fun <- log_guide_fun + log_resamp_weights
       }
       log_s_not_1_weights <- log_guide_fun - log_filter_guide_fun
       if (!(s==1 & nt!=0)){
@@ -456,7 +462,7 @@ igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
           ),
           error = function (e) {
             stop(ep,"error in calculation of log_meas_weights: ",
-                 conditionMessage(e),call.=FALSE)
+              conditionMessage(e),call.=FALSE)
           }
         )
         gnsi <- FALSE
@@ -467,7 +473,7 @@ igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
           coef(object,transform=TRUE) <- apply(params,1L,weighted.mean,w=exp(log_weights))
         } else {
           warning("igirf: ","filtering failure at last filter iteration; using ",
-                "unweighted mean for point estimate.")
+            "unweighted mean for point estimate.")
           coef(object,transform=TRUE) <- apply(params,1L,mean)
         }
       }
@@ -476,16 +482,16 @@ igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
         log_weights <- log_weights - max_log_weights
         weights <- exp(log_weights)
         xx <- tryCatch(
-          .Call('girf_computations',
-                x=X,
-                params=params,
-                Np=Np[nt+1],
-                trackancestry=FALSE,
-                doparRS=TRUE,
-                weights=weights,
-                lgps=log_guide_fun,
-                fsv=fcst_samp_var,
-                tol=tol
+          .Call(girf_computations,
+            x=X,
+            params=params,
+            Np=Np[nt+1],
+            trackancestry=FALSE,
+            doparRS=TRUE,
+            weights=weights,
+            lgps=log_guide_fun,
+            fsv=fcst_samp_var,
+            tol=tol
           ),
           error = function (e) {
             stop(ep,conditionMessage(e),call.=FALSE) # nocov
@@ -519,8 +525,8 @@ igirf.momgirf <- function (object, params, Ninter, lookahead, Nguide,
 }
 
 igirf.bootgirf <- function (object, params, Ninter, lookahead, Nguide,
-                            Np, girfiter, rw.sd, cooling.fn, tol,
-                            ..., verbose, .indices = integer(0), .gnsi = TRUE) {
+  Np, girfiter, rw.sd, cooling.fn, tol,
+  ..., verbose, .indices = integer(0), .gnsi = TRUE) {
 
   tol <- as.numeric(tol)
   gnsi <- as.logical(.gnsi)
@@ -540,7 +546,6 @@ igirf.bootgirf <- function (object, params, Ninter, lookahead, Nguide,
   ntimes <- length(times)-1
   nunits <- length(unit_names(object))
 
-  loglik <- rep(NA,ntimes)
   cond.loglik <- array(0, dim = c(ntimes, Ninter))
 
   znames <- object@accumvars
@@ -548,36 +553,42 @@ igirf.bootgirf <- function (object, params, Ninter, lookahead, Nguide,
   log_filter_guide_fun <- array(0, dim = Np[1])
   for (nt in 0:(ntimes-1)) {
     pmag <- cooling.fn(nt,girfiter)$alpha*rw.sd[,nt]
-    params <- .Call("randwalk_perturbation_spatPomp",params,pmag,PACKAGE="spatPomp")
+    params <- .Call(randwalk_perturbation_spatPomp,params,pmag)
     tparams <- partrans(object,params,dir="fromEst",.gnsi=gnsi)
     if (nt == 0) {
       x <- rinit(object,params=tparams)
       statenames <- rownames(x)
-      paramnames <- rownames(tparams)
-      nvars <- nrow(x)
     }
     tt <- seq(from=times[nt+1],to=times[nt+2],length.out=Ninter+1)
-    lookahead_steps = min(lookahead, ntimes-nt)
-    # Four-dimensional array: nvars by nguide by ntimes by nreps
-    Xg = array(0, dim=c(length(statenames), Nguide, lookahead_steps, Np[1]), dimnames = list(nvars = statenames, ng = NULL, lookahead = 1:lookahead_steps, nreps = NULL))
-    x_with_guides <- x[,rep(1:Np[1], each = Nguide)]
-    tp_with_guides <- tparams[,rep(1:Np[1], each = Nguide)]
-    guidesim_index <- 1:Np[1] # the index for guide simulations (to be updated each time resampling occurs)
+    lookahead_steps <- min(lookahead, ntimes-nt)
+    ## Four-dimensional array: nvars by nguide by ntimes by nreps
+    Xg <- array(0,
+      dim=c(length(statenames), Nguide, lookahead_steps, Np[1]),
+      dimnames = list(
+        nvars = statenames,
+        ng = NULL,
+        lookahead = seq_len(lookahead_steps),
+        nreps = NULL
+      )
+    )
+    guidesim_index <- seq_len(Np[1]) ## the index for guide simulations (to be updated each time resampling occurs)
+    x_with_guides <- x[,rep(guidesim_index, each = Nguide)]
+    tp_with_guides <- tparams[,rep(guidesim_index, each = Nguide)]
     Xg <- rprocess(object, x0=x_with_guides, t0=times[nt+1], times=times[(nt+2):(nt+1+lookahead_steps)],
-                   params=tp_with_guides,.gnsi=gnsi)
+      params=tp_with_guides,.gnsi=gnsi)
     Xskel <- pomp::flow(object,
-                   x0=x,
-                   t0=times[nt+1],
-                   params=tparams,
-                   times = times[(nt+2):(nt+1+lookahead_steps)],
-                   method = 'adams')
+      x0=x,
+      t0=times[nt+1],
+      params=tparams,
+      times = times[(nt+2):(nt+1+lookahead_steps)],
+      method = 'adams')
     resids <- Xg - Xskel[,rep(1:Np[1], each=Nguide),,drop=FALSE] # residuals
     rm(Xg, Xskel, x_with_guides)
     for (s in 1:Ninter){
       tparams <- partrans(object,params,dir="fromEst",.gnsi=gnsi)
       tp_with_guides <- tparams[,rep(1:Np[1], rep(Nguide, Np[1]))]
       X <- rprocess(object,x0=x, t0 = tt[s], times= tt[s+1],
-                    params=tparams,.gnsi=gnsi)
+        params=tparams,.gnsi=gnsi)
       if(s>1 && length(znames)>0){
         x.znames <- x[znames,]; dim(x.znames) <- c(dim(x.znames),1)
         X[znames,,] <- X[znames,,,drop=FALSE] + x.znames
@@ -585,11 +596,11 @@ igirf.bootgirf <- function (object, params, Ninter, lookahead, Nguide,
       X.start <- X[,,1]
       if(tt[s+1] < times[nt + 1 + lookahead_steps]){
         skel <- pomp::flow(object,
-                   x0=X.start,
-                   t0=tt[s+1],
-                   params=tparams,
-                   times = times[(nt + 1 + 1):(nt + 1 + lookahead_steps)],
-                   method = 'adams')
+          x0=X.start,
+          t0=tt[s+1],
+          params=tparams,
+          times = times[(nt + 1 + 1):(nt + 1 + lookahead_steps)],
+          method = 'adams')
         if(length(znames) > 0){
           skel.start <- skel[,,1]
           X.start.znames <- X.start[znames,]
@@ -600,36 +611,36 @@ igirf.bootgirf <- function (object, params, Ninter, lookahead, Nguide,
       } else {
         skel <- X
       }
-      log_guide_fun = vector(mode = "numeric", length = Np[1]) + 1
+      log_guide_fun <- vector(mode = "numeric", length = Np[1]) + 1
 
       for(l in 1:lookahead_steps){
-        if(nt+1+l-lookahead <= 0) discount_denom_init = object@t0
-        else discount_denom_init = times[nt+1+l - lookahead]
-        discount_factor = 1 - (times[nt+1+l] - tt[s+1])/(times[nt+1+l] - discount_denom_init)/ifelse(lookahead==1,2,1) ## to ensure that the discount factor does not become too small for L=1 and small s (which can lead to very uninformative guide function), increase the discount factor to at least 1/2 when L=1.
+        if(nt+1+l-lookahead <= 0) discount_denom_init <- object@t0
+        else discount_denom_init <- times[nt+1+l - lookahead]
+        discount_factor <- 1 - (times[nt+1+l] - tt[s+1])/(times[nt+1+l] - discount_denom_init)/ifelse(lookahead==1,2,1) ## to ensure that the discount factor does not become too small for L=1 and small s (which can lead to very uninformative guide function), increase the discount factor to at least 1/2 when L=1.
 
-        # construct pseudo-simulations by adding simulated noise terms (residuals) to the skeletons
+                                        # construct pseudo-simulations by adding simulated noise terms (residuals) to the skeletons
         pseudosims <- skel[,rep(1:Np[1], each=Nguide),l,drop=FALSE] +
           resids[,rep(guidesim_index-1, each=Nguide)*Nguide+rep(1:Nguide, Np[1]),l,drop=FALSE] -
           resids[,rep(guidesim_index-1, each=Nguide)*Nguide+rep(1:Nguide, Np[1]),1,drop=FALSE] +
           resids[,rep(guidesim_index-1, each=Nguide)*Nguide+rep(1:Nguide, Np[1]),1,drop=FALSE] * sqrt((times[nt+2]-tt[s+1])/(times[nt+2]-times[nt+1]))
         rm(skel)
         log_dmeas_weights <- tryCatch(
-          (vec_dmeasure(
-            object,
-            y=object@data[,nt+l,drop=FALSE],
-            x=pseudosims,
-            times=times[nt+1+l],
-            params=tp_with_guides,
-            log=TRUE,
-            .gnsi=gnsi
-          )),
-          error = function (e) {
-            stop(ep,"error in calculation of log_dmeas_weights: ",
-                 conditionMessage(e),call.=FALSE)
-          }
+        (vec_dmeasure(
+          object,
+          y=object@data[,nt+l,drop=FALSE],
+          x=pseudosims,
+          times=times[nt+1+l],
+          params=tp_with_guides,
+          log=TRUE,
+          .gnsi=gnsi
+        )),
+        error = function (e) {
+          stop(ep,"error in calculation of log_dmeas_weights: ",
+            conditionMessage(e),call.=FALSE)
+        }
         )
         if(any(is.na(log_dmeas_weights))){
-          # find particle with the NA
+                                        # find particle with the NA
           na_ix <- which(is.na(log_dmeas_weights[,,1]))[1]
           na_ix_col <- (na_ix %/% nunits) + (na_ix %% nunits > 0)
           illegal_dunit_measure_error(
@@ -665,7 +676,7 @@ igirf.bootgirf <- function (object, params, Ninter, lookahead, Nguide,
           ),
           error = function (e) {
             stop(ep,"error in calculation of log_meas_weights: ",
-                 conditionMessage(e),call.=FALSE)
+              conditionMessage(e),call.=FALSE)
           }
         )
         gnsi <- FALSE
@@ -676,7 +687,7 @@ igirf.bootgirf <- function (object, params, Ninter, lookahead, Nguide,
           coef(object,transform=TRUE) <- apply(params,1L,weighted.mean,w=exp(log_weights))
         } else {
           pWarn("ibootgirf","filtering failure at last filter iteration; using ",
-                       "unweighted mean for point estimate.")
+            "unweighted mean for point estimate.")
           coef(object,transform=TRUE) <- apply(params,1L,mean)
         }
       }
@@ -685,16 +696,16 @@ igirf.bootgirf <- function (object, params, Ninter, lookahead, Nguide,
         log_weights <- log_weights - max_log_weights
         weights <- exp(log_weights)
         xx <- tryCatch(
-          .Call('girf_computations',
-                x=X,
-                params=params,
-                Np=Np[nt+1],
-                trackancestry=TRUE,
-                doparRS=TRUE,
-                weights=weights,
-                lgps=log_guide_fun,
-                fsv=array(0,dim=c(length(unit_names(object)), lookahead_steps, Np[1])), # bootgirf2 doesn't use fsv, set to an arbitrary val.
-                tol=tol
+          .Call(girf_computations,
+            x=X,
+            params=params,
+            Np=Np[nt+1],
+            trackancestry=TRUE,
+            doparRS=TRUE,
+            weights=weights,
+            lgps=log_guide_fun,
+            fsv=array(0,dim=c(length(unit_names(object)), lookahead_steps, Np[1])), # bootgirf2 doesn't use fsv, set to an arbitrary val.
+            tol=tol
           ),
           error = function (e) {
             stop(ep,conditionMessage(e),call.=FALSE) # nocov
@@ -705,7 +716,6 @@ igirf.bootgirf <- function (object, params, Ninter, lookahead, Nguide,
         x <- xx$states
         log_filter_guide_fun <- xx$logfilterguides
         params <- xx$params
-        fcst_samp_var <- xx$newfsv
       }
       else{
         cond.loglik[nt+1, s] <- log(tol)
@@ -741,7 +751,7 @@ illegal_dunit_measure_error <- function(time, lik, datvals, states, params){
 igirf_rw_sd_times <- function(times, Ninter){
   rw_sd_times <- c()
   for(i in seq(length(times)-1)) rw_sd_times <- c(
-    rw_sd_times, seq(from=times[i],to=times[i+1],length.out=Ninter+1))
+                                   rw_sd_times, seq(from=times[i],to=times[i+1],length.out=Ninter+1))
   return(rw_sd_times)
 }
 
